#ifndef MID2226_CONST_H
#define MID2226_CONST_H


#ifdef ISDLLBUILD
    #define MID2226_API extern "C" __declspec(dllexport)
#else
#ifdef __cplusplus
    #define MID2226_API extern "C" __declspec(dllimport)
#else
    #define MID2226_API __declspec(dllimport)
#endif
#endif



typedef struct {
 UINT32 serial_number;
 UCHAR  month;
 UCHAR  day;
 UCHAR  year;
} SN2226;

typedef struct s2226_device_info
{
    int boardNum;
    SN2226 serialNumber;
} DEVINFO2226;



/** Video input source.  Note: Changing input may stop MPEG Video Stream
 * @param MID2226_INPUT_COMPOSITE_0 Composite channel 0
 * @param MID2226_INPUT_SVIDEO_0 S-Video Channel 0
 * @param MID2226_INPUT_NUM maximum number of inputs
 */
typedef enum
{
    MID2226_INPUT_COMPOSITE_0       = 0,
    MID2226_INPUT_SVIDEO_0          = 1,
    MID2226_INPUT_COMPOSITE_1       = 2,
    MID2226_INPUT_SVIDEO_1          = 3,
    MID2226_INPUT_SD_COLORBARS      = 4,
    MID2226_INPUT_720P_COLORBARS    = 5,
    MID2226_INPUT_1080I_COLORBARS   = 6,
    MID2226_INPUT_SDI_SD            = 7,
    MID2226_INPUT_SDI_720P          = 8,   // NTSC only( PAL 720P 50Hz is not currently available)
    MID2226_INPUT_SDI_1080I         = 9,  
    //MID2226_INPUT_NUM               = 10    // maximum number of inputs
    MID2226_INPUT_1080P30_COLORBARS = 10,
    MID2226_INPUT_1080P24_COLORBARS = 11,
    MID2226_INPUT_720P24_COLORBARS  = 12,
    MID2226_INPUT_SDI_1080P30       = 13,  // 30Hz and 29.97Hz. (overlay only. not supported for record/playback)
    MID2226_INPUT_SDI_1080P24       = 14,  // 24Hz and 23.98Hz.
    MID2226_INPUT_SDI_720P24        = 15,  // 24Hz and 23.98Hz.
    MID2226_INPUT_NUM               = 16   // maximum number of inputs
} MID2226_INPUT;

typedef enum
{
    MID2226_DECODE_480I,  //NTSC
    MID2226_DECODE_576I,  //PAL
    // Note : MID2226_DECODE
    MID2226_DECODE_720P_50, //NTSC
    MID2226_DECODE_720P_5994, //NTSC
    MID2226_DECODE_720P_60,   //NTSC
    MID2226_DECODE_1080I_50,  //PAL setting
    MID2226_DECODE_1080I_5994, //NTSC
    MID2226_DECODE_1080I_60,   //NTSC
    MID2226_DECODE_720P_2398,  
    MID2226_DECODE_720P_24  ,  
    MID2226_DECODE_1080P_2398, 
    MID2226_DECODE_1080P_24    
} MID2226_DECODE_TYPE;

typedef enum
{
    AMUX_MPEG_IN_LINE_IN   , // MPEG-In  gets Line-In
    AMUX_MPEG_IN_TONE      , // MPEG-In  gets Tone Test
    AMUX_MPEG_IN_SDI_IN      // MPEG-In  gets SDI-In embedded audio
} MID2226_MUX_MPEG_IN_TYPE;

typedef enum
{
    AMUX_LINE_OUT_LINE_IN  , // Line-Out gets Line-In
    AMUX_LINE_OUT_MPEG_OUT , // Line-Out gets MPEG-Out
    AMUX_LINE_OUT_SDI_IN     // Line-Out gets SDI-In embedded audio
} MID2226_MUX_LINE_OUT_TYPE;

typedef enum
{
    AMUX_SDI_OUT_LINE_IN   , // SDI-Out  gets Line-In
    AMUX_SDI_OUT_MPEG_OUT  , // SDI-Out  gets MPEG-Out
    AMUX_SDI_OUT_TONE      , // SDI-Out  gets Tone Test
    AMUX_SDI_OUT_SDI_IN      // SDI-Out  gets SDI-In embedded audio
} MID2226_MUX_SDI_OUT_TYPE;

typedef enum
{
    MID2226_PREVIEWTYPE_DECODED = 0,  // Supported on Windows 7 only
    MID2226_PREVIEWTYPE_RAW = 1,    // Raw preview
} MID2226_PREVIEWTYPE;

#define MID2226_RAWPREVIEW_320_240 1 // small raw preview size (320x240)
#define MID2226_RAWPREVIEW_640_480 2 // large raw preview size (640x480)
#define MID2226_RAWPREVIEW_1280_720 3// 1280x720 preview(10fps max will not be at full frame rate)
#define MID2226_RAWPREVIEW_1920_1080 4 // 1920x1080 preview (3fps max)

// error constants 
#define MID2226_SUCCESS             0
#define MID2226_ERR_NONE            0
#define MID2226_ERR_UNSPECIFIED     -1
#define MID2226_ERR_CAPTURING       -2  // already capturing/recording
#define MID2226_ERR_NOTCAPTURING    -3  // not capturing/recording
#define MID2226_ERR_RUNNING         -4  // attempt to set configuration while graph running
#define MID2226_ERR_SNAPSHOT        -5  // currently displaying snapshot
#define MID2226_ERR_INVALIDFILE     -6  // invalid file
#define MID2226_ERR_DIRECTX         -7  // directX error( other specific directX errors are possible)
#define MID2226_ERR_NODEVICE        -8  // device not present
#define MID2226_ERR_NOTINITIALIZED  -9  // initialization function failed or not called
#define MID2226_ERR_INVALIDMODE     -10 // invalid mode(eg.  record in MJPEG CAPTURE mode)
#define MID2226_ERR_FWVERSION       -11 // For raw preview.  Firmware version not supported. Get firmware upgrade
                                        // from website
#define MID2226_ERR_DRIVER          -12 // driver does not support this feature(out of date driver?)
#define MID2226_ERR_SETOUTPUT       -13 // Raw capture not available if S2226_SetOutput is set to scaled output

#define MID2226_SNAP_ERR_UNSPECIFIED -1
#define MID2226_SNAP_ERR_BUFSIZE     -2  // 'Size' of buffer provided is too small for snapshot.
#define MID2226_SNAP_ERR_BIST        -3  // Built in self test failed. Hardware not ready.
#define MID2226_SNAP_ERR_SYNCH       -4  // Aquisition's synchronization loop timed out.
#define MID2226_SNAP_ERR_CRITSEC     -5  // Aquisition's critical section already locked, and user doesn't want to wait for it.
#define MID2226_SNAP_ERR_PARTBUF     -6  // Didn't recieve a full frame of data.
#define MID2226_SNAP_ERR_DVBUF       -7  // Failed to get current frame buffer from DV
#define MID2226_SNAP_ERR_DVGRAB      -8  // The DV frame grabber was not setup
#define MID2226_SNAP_ERR_USERERR     -9  // Error returned from user's merge function

typedef enum
{
    MID2226_VIDSYS_PAL=1,
    MID2226_VIDSYS_NTSC=2
} MID2226_VIDSYS;

/**\defgroup VIDEO_LEVELS Video levels 
  */
#define MID2226_LEVEL_CONTRAST      1 /**< \ingroup VIDEO_LEVELS */
#define MID2226_LEVEL_BRIGHTNESS    2 /**< \ingroup VIDEO_LEVELS */
#define MID2226_LEVEL_SATURATION    4 /**< \ingroup VIDEO_LEVELS Deprecated*/
#define MID2226_LEVEL_HUE           8 /**< \ingroup VIDEO_LEVELS Deprecated*/
#define MID2246_LEVEL_SATURATION_CR 4 /**< \ingroup VIDEO_LEVELS */
#define MID2246_LEVEL_SATURATION_CB 8 /**< \ingroup VIDEO_LEVELS */


/** General Status information
 * @param bIsRecording true if currently recording
 * @param bIsRunning true if running (previewing, decoding, recording, or streaming).
 * @param iFilesize current recorded file size
 * @param szFilepath current filepath being recorded
 */
typedef struct 
{ 
    ULONG       iFilesize;              // current recorded size(megs)
    char        szFilepath[MAX_PATH];   // current filepath
    BOOL        bIsRecording;           // true if recording to file
    BOOL        bIsRunning;             // true if DirectShow graph is running (preview, decode, recording, streaming/callbacks)
} MID2226STATUS; 

// unicode version
typedef struct 
{ 
    ULONG       iFilesize;              // current recorded size(megs)
    wchar_t     szFilepath[MAX_PATH];   // current filepath
    BOOL        bIsRecording;           // true if recording to file
    BOOL        bIsRunning;             // true if DirectShow graph is running (preview, decode, streaming/callbacks)
} MID2226STATUS_W; 

//////////////////////////////////////////////////////////////////////////
// Overlay
// Caption region display mask
//////////////////////////////////////////////////////////////////////////

#define MID2226_REGION_MONITOR      1
#define MID2226_REGION_MPEG         2
#define MID2226_REGION_STILL        4

//////////////////////////////////////////////////////////////////////////
// Snapshot
//////////////////////////////////////////////////////////////////////////
/** interlace field merge algorithms.  
 *  @param MID2226_FIELDALG_NONE no field manipulation is done
 *  @param MID2226_FIELDALG_DUP  duplicate field 0 
 *  @param MID2226_FIELDALG_MERGE merge field 0 and 1
 *  @param MID2226_FIELDALG_INTER interpolate between field 0
 */
#ifdef __cplusplus
enum MID2226_FIELDALG
#else
typedef enum
#endif
{
    MID2226_FIELDALG_NONE  = 0,   // no field manipulation is done
    MID2226_FIELDALG_DUP   = 1,   // duplicate field 0 
    MID2226_FIELDALG_MERGE = 2,  // merge field 0 and 1
    MID2226_FIELDALG_INTER = 3,  // interpolate between field 0
#ifdef __cplusplus
};
#else
} MID2226_FIELDALG;
#endif

// Image file save bitmask types 
#define MID2226_FILE_JPEG           1
#define MID2226_FILE_BMP            2
#define MID2226_FILE_PPM            4

// Call back definition for the user defined field merge routines
#ifndef SENSORAY_OS_LINUX
 #define MID2226_MERGEAPI int __stdcall
#else
 // SENSORAY_OS_LINUX
 #define MID2226_MERGEAPI int
#endif

#endif
